
Keras Multi-Head
================


.. image:: https://travis-ci.org/CyberZHG/keras-multi-head.svg
   :target: https://travis-ci.org/CyberZHG/keras-multi-head
   :alt: Travis


.. image:: https://coveralls.io/repos/github/CyberZHG/keras-multi-head/badge.svg?branch=master
   :target: https://coveralls.io/github/CyberZHG/keras-multi-head
   :alt: Coverage


.. image:: https://img.shields.io/pypi/pyversions/keras-multi-head.svg
   :target: https://pypi.org/project/keras-multi-head/
   :alt: PyPI


A wrapper layer for stacking layers horizontally.

Install
-------

.. code-block:: bash

   pip install keras-multi-head

Usage
-----

.. code-block:: python


